<?php
/**
 * @copyright Copyright (c) 2017 Lukas Reschke <lukas@statuscode.ch>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\TermsOfService\Db\Mapper;

use OCP\IL10N;

class CountryMapper {

	public const GLOBAL = '--';

	/** @var IL10N */
	private $l;

	public function __construct(IL10N $l10n) {
		$this->l = $l10n;
	}

	/**
	 * Whether the specified country code exists
	 *
	 * @param string|null $countryCode
	 * @return bool
	 */
	public function isValidCountry($countryCode): bool {
		return isset($this->getCountries()[$countryCode]);
	}

	/**
	 * Gets the countries as well as the two-letter code
	 *
	 * @return array
	 */
	public function getCountries(): array {
		$countries = [
			self::GLOBAL => $this->l->t('Global'),
			'AF' => $this->l->t('Afghanistan'),
			'AX' => $this->l->t('Åland Islands'),
			'AL' => $this->l->t('Albania'),
			'DZ' => $this->l->t('Algeria'),
			'AS' => $this->l->t('American Samoa'),
			'AD' => $this->l->t('Andorra'),
			'AO' => $this->l->t('Angola'),
			'AI' => $this->l->t('Anguilla'),
			'AQ' => $this->l->t('Antarctica'),
			'AG' => $this->l->t('Antigua and Barbuda'),
			'AR' => $this->l->t('Argentina'),
			'AM' => $this->l->t('Armenia'),
			'AW' => $this->l->t('Aruba'),
			'AU' => $this->l->t('Australia'),
			'AT' => $this->l->t('Austria'),
			'AZ' => $this->l->t('Azerbaijan'),
			'BS' => $this->l->t('Bahamas'),
			'BH' => $this->l->t('Bahrain'),
			'BD' => $this->l->t('Bangladesh'),
			'BB' => $this->l->t('Barbados'),
			'BY' => $this->l->t('Belarus'),
			'BE' => $this->l->t('Belgium'),
			'BZ' => $this->l->t('Belize'),
			'BJ' => $this->l->t('Benin'),
			'BM' => $this->l->t('Bermuda'),
			'BT' => $this->l->t('Bhutan'),
			'BO' => $this->l->t('Bolivia (Plurinational State of)'),
			'BQ' => $this->l->t('Bonaire, Sint Eustatius and Saba'),
			'BA' => $this->l->t('Bosnia and Herzegovina'),
			'BW' => $this->l->t('Botswana'),
			'BV' => $this->l->t('Bouvet Island'),
			'BR' => $this->l->t('Brazil'),
			'IO' => $this->l->t('British Indian Ocean Territory'),
			'BN' => $this->l->t('Brunei Darussalam'),
			'BG' => $this->l->t('Bulgaria'),
			'BF' => $this->l->t('Burkina Faso'),
			'BI' => $this->l->t('Burundi'),
			'CV' => $this->l->t('Cabo Verde'),
			'KH' => $this->l->t('Cambodia'),
			'CM' => $this->l->t('Cameroon'),
			'CA' => $this->l->t('Canada'),
			'KY' => $this->l->t('Cayman Islands'),
			'CF' => $this->l->t('Central African Republic'),
			'TD' => $this->l->t('Chad'),
			'CL' => $this->l->t('Chile'),
			'CN' => $this->l->t('China'),
			'CX' => $this->l->t('Christmas Island'),
			'CC' => $this->l->t('Cocos (Keeling) Islands'),
			'CO' => $this->l->t('Colombia'),
			'KM' => $this->l->t('Comoros'),
			'CG' => $this->l->t('Congo'),
			'CD' => $this->l->t('Congo (Democratic Republic of the)'),
			'CK' => $this->l->t('Cook Islands'),
			'CR' => $this->l->t('Costa Rica'),
			'CI' => $this->l->t('Côte d\'Ivoire'),
			'HR' => $this->l->t('Croatia'),
			'CU' => $this->l->t('Cuba'),
			'CW' => $this->l->t('Curaçao'),
			'CY' => $this->l->t('Cyprus'),
			'CZ' => $this->l->t('Czechia'),
			'DK' => $this->l->t('Denmark'),
			'DJ' => $this->l->t('Djibouti'),
			'DM' => $this->l->t('Dominica'),
			'DO' => $this->l->t('Dominican Republic'),
			'EC' => $this->l->t('Ecuador'),
			'EG' => $this->l->t('Egypt'),
			'SV' => $this->l->t('El Salvador'),
			'GQ' => $this->l->t('Equatorial Guinea'),
			'ER' => $this->l->t('Eritrea'),
			'EE' => $this->l->t('Estonia'),
			'ET' => $this->l->t('Ethiopia'),
			'FK' => $this->l->t('Falkland Islands (Malvinas)'),
			'FO' => $this->l->t('Faroe Islands'),
			'FJ' => $this->l->t('Fiji'),
			'FI' => $this->l->t('Finland'),
			'FR' => $this->l->t('France'),
			'GF' => $this->l->t('French Guiana'),
			'PF' => $this->l->t('French Polynesia'),
			'TF' => $this->l->t('French Southern Territories'),
			'GA' => $this->l->t('Gabon'),
			'GM' => $this->l->t('Gambia'),
			'GE' => $this->l->t('Georgia'),
			'DE' => $this->l->t('Germany'),
			'GH' => $this->l->t('Ghana'),
			'GI' => $this->l->t('Gibraltar'),
			'GR' => $this->l->t('Greece'),
			'GL' => $this->l->t('Greenland'),
			'GD' => $this->l->t('Grenada'),
			'GP' => $this->l->t('Guadeloupe'),
			'GU' => $this->l->t('Guam'),
			'GT' => $this->l->t('Guatemala'),
			'GG' => $this->l->t('Guernsey'),
			'GN' => $this->l->t('Guinea'),
			'GW' => $this->l->t('Guinea-Bissau'),
			'GY' => $this->l->t('Guyana'),
			'HT' => $this->l->t('Haiti'),
			'HM' => $this->l->t('Heard Island and McDonald Islands'),
			'VA' => $this->l->t('Holy See'),
			'HN' => $this->l->t('Honduras'),
			'HK' => $this->l->t('Hong Kong'),
			'HU' => $this->l->t('Hungary'),
			'IS' => $this->l->t('Iceland'),
			'IN' => $this->l->t('India'),
			'ID' => $this->l->t('Indonesia'),
			'IR' => $this->l->t('Iran (Islamic Republic of)'),
			'IQ' => $this->l->t('Iraq'),
			'IE' => $this->l->t('Ireland'),
			'IM' => $this->l->t('Isle of Man'),
			'IL' => $this->l->t('Israel'),
			'IT' => $this->l->t('Italy'),
			'JM' => $this->l->t('Jamaica'),
			'JP' => $this->l->t('Japan'),
			'JE' => $this->l->t('Jersey'),
			'JO' => $this->l->t('Jordan'),
			'KZ' => $this->l->t('Kazakhstan'),
			'KE' => $this->l->t('Kenya'),
			'KI' => $this->l->t('Kiribati'),
			'KP' => $this->l->t('Korea (Democratic People\'s Republic of)'),
			'KR' => $this->l->t('Korea (Republic of)'),
			'KW' => $this->l->t('Kuwait'),
			'KG' => $this->l->t('Kyrgyzstan'),
			'LA' => $this->l->t('Lao People\'s Democratic Republic'),
			'LV' => $this->l->t('Latvia'),
			'LB' => $this->l->t('Lebanon'),
			'LS' => $this->l->t('Lesotho'),
			'LR' => $this->l->t('Liberia'),
			'LY' => $this->l->t('Libya'),
			'LI' => $this->l->t('Liechtenstein'),
			'LT' => $this->l->t('Lithuania'),
			'LU' => $this->l->t('Luxembourg'),
			'MO' => $this->l->t('Macao'),
			'MK' => $this->l->t('Macedonia (the former Yugoslav Republic of)'),
			'MG' => $this->l->t('Madagascar'),
			'MW' => $this->l->t('Malawi'),
			'MY' => $this->l->t('Malaysia'),
			'MV' => $this->l->t('Maldives'),
			'ML' => $this->l->t('Mali'),
			'MT' => $this->l->t('Malta'),
			'MH' => $this->l->t('Marshall Islands'),
			'MQ' => $this->l->t('Martinique'),
			'MR' => $this->l->t('Mauritania'),
			'MU' => $this->l->t('Mauritius'),
			'YT' => $this->l->t('Mayotte'),
			'MX' => $this->l->t('Mexico'),
			'FM' => $this->l->t('Micronesia (Federated States of)'),
			'MD' => $this->l->t('Moldova (Republic of)'),
			'MC' => $this->l->t('Monaco'),
			'MN' => $this->l->t('Mongolia'),
			'ME' => $this->l->t('Montenegro'),
			'MS' => $this->l->t('Montserrat'),
			'MA' => $this->l->t('Morocco'),
			'MZ' => $this->l->t('Mozambique'),
			'MM' => $this->l->t('Myanmar'),
			'NA' => $this->l->t('Namibia'),
			'NR' => $this->l->t('Nauru'),
			'NP' => $this->l->t('Nepal'),
			'NL' => $this->l->t('Netherlands'),
			'NC' => $this->l->t('New Caledonia'),
			'NZ' => $this->l->t('New Zealand'),
			'NI' => $this->l->t('Nicaragua'),
			'NE' => $this->l->t('Niger'),
			'NG' => $this->l->t('Nigeria'),
			'NU' => $this->l->t('Niue'),
			'NF' => $this->l->t('Norfolk Island'),
			'MP' => $this->l->t('Northern Mariana Islands'),
			'NO' => $this->l->t('Norway'),
			'OM' => $this->l->t('Oman'),
			'PK' => $this->l->t('Pakistan'),
			'PW' => $this->l->t('Palau'),
			'PS' => $this->l->t('Palestine, State of'),
			'PA' => $this->l->t('Panama'),
			'PG' => $this->l->t('Papua New Guinea'),
			'PY' => $this->l->t('Paraguay'),
			'PE' => $this->l->t('Peru'),
			'PH' => $this->l->t('Philippines'),
			'PN' => $this->l->t('Pitcairn'),
			'PL' => $this->l->t('Poland'),
			'PT' => $this->l->t('Portugal'),
			'PR' => $this->l->t('Puerto Rico'),
			'QA' => $this->l->t('Qatar'),
			'RE' => $this->l->t('Réunion'),
			'RO' => $this->l->t('Romania'),
			'RU' => $this->l->t('Russian Federation'),
			'RW' => $this->l->t('Rwanda'),
			'BL' => $this->l->t('Saint Barthélemy'),
			'SH' => $this->l->t('Saint Helena, Ascension and Tristan da Cunha'),
			'KN' => $this->l->t('Saint Kitts and Nevis'),
			'LC' => $this->l->t('Saint Lucia'),
			'MF' => $this->l->t('Saint Martin (French part)'),
			'PM' => $this->l->t('Saint Pierre and Miquelon'),
			'VC' => $this->l->t('Saint Vincent and the Grenadines'),
			'WS' => $this->l->t('Samoa'),
			'SM' => $this->l->t('San Marino'),
			'ST' => $this->l->t('Sao Tome and Principe'),
			'SA' => $this->l->t('Saudi Arabia'),
			'SN' => $this->l->t('Senegal'),
			'RS' => $this->l->t('Serbia'),
			'SC' => $this->l->t('Seychelles'),
			'SL' => $this->l->t('Sierra Leone'),
			'SG' => $this->l->t('Singapore'),
			'SX' => $this->l->t('Sint Maarten (Dutch part)'),
			'SK' => $this->l->t('Slovakia'),
			'SI' => $this->l->t('Slovenia'),
			'SB' => $this->l->t('Solomon Islands'),
			'SO' => $this->l->t('Somalia'),
			'ZA' => $this->l->t('South Africa'),
			'GS' => $this->l->t('South Georgia and the South Sandwich Islands'),
			'SS' => $this->l->t('South Sudan'),
			'ES' => $this->l->t('Spain'),
			'LK' => $this->l->t('Sri Lanka'),
			'SD' => $this->l->t('Sudan'),
			'SR' => $this->l->t('Suriname'),
			'SJ' => $this->l->t('Svalbard and Jan Mayen'),
			'SZ' => $this->l->t('Swaziland'),
			'SE' => $this->l->t('Sweden'),
			'CH' => $this->l->t('Switzerland'),
			'SY' => $this->l->t('Syrian Arab Republic'),
			'TW' => $this->l->t('Taiwan'),
			'TJ' => $this->l->t('Tajikistan'),
			'TZ' => $this->l->t('Tanzania, United Republic of'),
			'TH' => $this->l->t('Thailand'),
			'TL' => $this->l->t('Timor-Leste'),
			'TG' => $this->l->t('Togo'),
			'TK' => $this->l->t('Tokelau'),
			'TO' => $this->l->t('Tonga'),
			'TT' => $this->l->t('Trinidad and Tobago'),
			'TN' => $this->l->t('Tunisia'),
			'TR' => $this->l->t('Turkey'),
			'TM' => $this->l->t('Turkmenistan'),
			'TC' => $this->l->t('Turks and Caicos Islands'),
			'TV' => $this->l->t('Tuvalu'),
			'UG' => $this->l->t('Uganda'),
			'UA' => $this->l->t('Ukraine'),
			'AE' => $this->l->t('United Arab Emirates'),
			'GB' => $this->l->t('United Kingdom of Great Britain and Northern Ireland'),
			'US' => $this->l->t('United States of America'),
			'UM' => $this->l->t('United States Minor Outlying Islands'),
			'UY' => $this->l->t('Uruguay'),
			'UZ' => $this->l->t('Uzbekistan'),
			'VU' => $this->l->t('Vanuatu'),
			'VE' => $this->l->t('Venezuela (Bolivarian Republic of)'),
			'VN' => $this->l->t('Viet Nam'),
			'VG' => $this->l->t('Virgin Islands (British)'),
			'VI' => $this->l->t('Virgin Islands (U.S.)'),
			'WF' => $this->l->t('Wallis and Futuna'),
			'EH' => $this->l->t('Western Sahara'),
			'YE' => $this->l->t('Yemen'),
			'ZM' => $this->l->t('Zambia'),
			'ZW' => $this->l->t('Zimbabwe'),
		];

		return $countries;
	}
}
